openadr3.vtn.mqtt

MQTT publisher component using machine_head (Paho).

MQTT publisher component using machine_head (Paho).
raw docstring

connected?clj

(connected? publisher)

Returns true if the publisher has an active MQTT connection.

Returns true if the publisher has an active MQTT connection.
sourceraw docstring

new-mqtt-publisherclj

(new-mqtt-publisher)

Create an MqttPublisher component. Depends on :config.

Create an MqttPublisher component. Depends on :config.
sourceraw docstring

publish!clj

(publish! publisher topic payload)

Publish a message to an MQTT topic.

payload is a Clojure map that will be JSON-encoded. Options via config: :mqtt-retained — whether messages are retained (default false)

Uses QoS 1 (at least once delivery).

Publish a message to an MQTT topic.

payload is a Clojure map that will be JSON-encoded.
Options via config:
  :mqtt-retained — whether messages are retained (default false)

Uses QoS 1 (at least once delivery).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries