Notifying storage decorator. Wraps any VtnStorage implementation and publishes MQTT notifications on create, update, and delete operations. Reads delegate unchanged.
Callers can suppress the notification for an individual write by
attaching ^:suppress-notify metadata to the input map — used by
bulk historical backfill to avoid flooding MQTT subscribers with
notifications for stale events.
As a Component, depends on :validated-storage and :notifier.
Notifying storage decorator. Wraps any VtnStorage implementation and publishes MQTT notifications on create, update, and delete operations. Reads delegate unchanged. Callers can suppress the notification for an individual write by attaching `^:suppress-notify` metadata to the input map — used by bulk historical backfill to avoid flooding MQTT subscribers with notifications for stale events. As a Component, depends on :validated-storage and :notifier.
(new-notifying-storage)Create a NotifyingStorage component. Depends on :validated-storage and :notifier.
Create a NotifyingStorage component. Depends on :validated-storage and :notifier.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |